=========
Tutorials
=========

Pymunk has one tutorial that show a simple simulation from start to end.

After reading it make sure to also check out the :ref:`Examples <examples>` as 
most of them are easy to follow and showcase many of the things you can do with 
pymunk. Also take a look at the external tutorials. While they are not created 
by the Pymunk creator they can still give a good start in how to use Pymunk.

.. toctree:: 
    :maxdepth: 1
    :glob:

    tutorials/SlideAndPinJoint.rst

..
    tutorials/*

External Tutorials
==================

.. note::
    If you have made a tutorial that is using Pymunk in any way and want it 
    mentioned here please send me a link and I will happily add it.

Several Youtube users have created tutorials covering Pymunk. In addition to 
the list below, make sure to also directly search Youtube for Pymunk since 
not everything available is listed here:


Pymunk Basics
-------------

:subscript:`Created by Ear of Corn Programming. Retrieved 2021-03-07`

Youtube user Ear of Corn Programming has a comprehensive introduction to 
Pymunk together with Pygame over several videos.

.. raw:: html
    
    <iframe width="560" height="315" src="https://www.youtube.com/embed/videoseries?list=PL_N_kL9gRTm8lh7GxFHh3ym1RXi6I6c50" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>


Simulating physics in Python
----------------------------

:subscript:`Created by Clear Code. Retrieved 2020-07-09`

Youtube user Clear Code has nice introduction to using Pymunk together with 
Pygame.

.. raw:: html

    <iframe width="560" height="315" src="https://www.youtube.com/embed/YrNpkuVIFdg" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>


Breakout game in Python, Pyglet and Pymunk
------------------------------------------

:subscript:`Created by Attila Toth. Retrieved 2019-04-14`

Youtube user Attila Toth has created a series of Youtube videos that guide 
through creating a Breakout like game, similar to the breakout example that
is included with Pymunk. If you like his first series (Pymunk physics in 
Pyglet) then this is a great followup.

.. raw:: html

    <iframe width="560" height="315" src="https://www.youtube.com/embed/6CEjZ8W1xx0" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>


Pymunk physics in Pyglet
------------------------

:subscript:`Created by Attila Toth. Retrieved 2018-02-24`

Youtube user Attila Toth has created a series of Youtube videos that gives a 
good introduction of Pymunk. The videos covers among other things the 3 types 
of Bodies, the different Shapes and how to use sprite with Pyglet together 
with Pymunk. 

.. raw:: html

    <iframe width="560" height="315" src="https://www.youtube.com/embed/videoseries?list=PL1P11yPQAo7pH9SWZtWdmmLumbp_r19Hs" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>


